<?php

/**
 * Fired during plugin activation
 *
 * @link       https://author.vtumax.com
 * @since      1.0.0
 *
 * @package    Vtu_Max
 * @subpackage Vtu_Max/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Vtu_Max
 * @subpackage Vtu_Max/includes
 * @author     Ani Anthony <author@vtumax.com>
 */
 require_once ABSPATH . 'wp-admin/includes/upgrade.php';


class Vtu_Max_Activator {

   public static function activate() {
    ob_start();
    self::create_tables();
    self::add_custom_usermeta_fields(); 
    self::add_extra_roles();
    self::insert_to_tables();
    ob_end_clean(); 
}

private static function add_custom_usermeta_fields() {
    
    $user = wp_get_current_user();

    $default_values = array(
        'api_key' => '',
        'phone' => '',
        'pin' => '1234',
        'wallet_balance' => '0.00',
        'cashback' => '0.00',
        'referral_balance' => '0.00',
        'referral_code' => '',
        'referred_by' => '',
        'mfy_ref' => '',
        'pv_ref' => '',
        'vfd_ref' => '',
        'wema_bank' => '',
        'fidelity_bank' => '',
        'sterling_bank' => '',
    );

    foreach ($default_values as $field_key => $default_value) {
        $existing_value = get_user_meta($user->ID, $field_key, true);

        if ($existing_value === '') {
            if ($field_key === 'referral_code') {
                $default_value = $user->user_nicename;
            }

            update_user_meta($user->ID, $field_key, $default_value);
        }
    }
}

private static function add_extra_roles() {
        $roles = array('customer', 'reseller', 'agent');

        foreach ($roles as $role) {
            if (!get_role($role)) {
                add_role($role, ucfirst($role), array());
            }
        }
    }
    
    
  private static function insert_to_tables() {
    global $wpdb;
    
    $wpdb->query("
        INSERT INTO {$wpdb->prefix}vtu_max_network_id
        (id, network_id, sme_id, gifting_id, corporate_id, vtu_id, sharesell_id, network, network_status, vtu_status, sharesell_status, airtimepin_status, sme_status, gifting_status, corporate_status, datapin_status)
        VALUES
        (1, '1', '1', '1', '1', '1', '1', 'MTN', 'true', 'true', 'true', 'true', 'true', 'true', 'true', 'true'),
        (2, '2', '2', '2', '2', '2', '2', 'GLO', 'true', 'true', 'true', 'true', 'true', 'true', 'true', 'true'),
        (3, '3', '3', '3', '3', '3', '3', '9MOBILE', 'true', 'true', 'true', 'true', 'true', 'true', 'true', 'true'),
        (4, '4', '4', '4', '4', '4', '4', 'AIRTEL', 'true', 'true', 'true', 'true', 'true', 'true', 'true', 'true')
    ");

    $wpdb->query("
        INSERT INTO {$wpdb->prefix}vtu_max_exam_id
        (id, exam_id, provider, buying_price, customer_price, reseller_price, agent_price , provider_status)
        VALUES
        (1, '1', 'WAEC', 1800, 2100, 2000, 1900, 'true'),
        (2, '2', 'NECO', 800, 1000, 950, 850, 'true'),
        (3, '3', 'NABTEB', 950, 1200, 1100, 1050, 'true')
    ");

    $wpdb->query("
        INSERT INTO {$wpdb->prefix}vtu_max_electricity_id
        (id, electricity_id, provider, abbreviation, provider_status)
        VALUES
        (1, '1', 'Ikeja Electric', 'IE', 'true'),
        (2, '2', 'Eko Electric', 'EKEDC', 'true'),
        (3, '3', 'Kano Electric', 'KEDCO', 'true'),
        (4, '4', 'Port Harcourt Electric', 'PHEDC', 'true'),
        (5, '5', 'Jos Electric', 'JED', 'true'),
        (6, '6', 'Ibadan Electric', 'IBEDC', 'true'),
        (7, '7', 'Kaduna Electric', 'KEDC', 'true'),
        (8, '8', 'Abuja Electric', 'AEDC', 'true'),
        (9, '9', 'Enugu Electric', 'ENUGU', 'true'),
        (10, '10', 'Benin Electric', 'BENIN', 'true'),
        (11, '11', 'Yola Electric', 'YOLA', 'true')
    ");

    $wpdb->query("
        INSERT INTO {$wpdb->prefix}vtu_max_cable_id
        (id, cable_id, provider, provider_status)
        VALUES
        (1, '1', 'GOTV', 'true'),
        (2, '2', 'DSTV', 'true'),
        (3, '3', 'STARTIMES', 'true')
    ");

    $wpdb->query("
        INSERT INTO {$wpdb->prefix}vtu_max_apiconfigs
        (id, name, value)
        VALUES
        (1, 'monify_charges', '1.5'),
        (2, 'monify_token', ''),
        (3, 'monify_secret', ''),
        (4, 'monify_contract', ''),
        (5, 'monify_wema_status', 'false'),
        (6, 'monify_moniepoint_status', 'false'),
        (7, 'monify_fedelity_status', 'false'),
        (8, 'monify_sterling_status', 'false'),
        (9, 'monify_status', 'false'),
        (10, 'pv_charges', '1.5'),
        (11, 'pv_token', ''),
        (12, 'pv_status', 'false'),
        (13, 'pv_secret', ''),
        (14, 'pv_business', ''),
        (15, 'mtn_vtu_token', ''),
        (16, 'mtn_vtu_provider', ''),
        (17, 'mtn_sharesell_token', ''),
        (18, 'mtn_sharesell_provider', ''),
        (19, 'airtel_vtu_token', ''),
        (20, 'airtel_vtu_provider', ''),
        (21, 'airtel_sharesell_token', ''),
        (22, 'airtel_sharesell_provider', ''),
        (23, 'glo_vtu_token', ''),
        (24, 'glo_vtu_provider', ''),
        (25, 'glo_sharesell_token', ''),
        (26, 'glo_sharesell_provider', ''),
        (27, '9mobile_vtu_token', ''),
        (28, '9mobile_vtu_provider', ''),
        (29, '9mobile_sharesell_token', ''),
        (30, '9mobile_sharesell_provider', ''),
        (31, 'mtn_sme_token', ''),
        (32, 'mtn_sme_provider', ''),
        (33, 'mtn_gifting_token', ''),
        (34, 'mtn_gifting_provider', ''),
        (35, 'mtn_corporate_token', ''),
        (36, 'mtn_corporate_provider', ''),
        (37, 'airtel_sme_token', ''),
        (38, 'airtel_sme_provider', ''),
        (39, 'airtel_gifting_token', ''),
        (40, 'airtel_gifting_provider', ''),
        (41, 'airtel_corporate_token', ''),
        (42, 'airtel_corporate_provider', ''),
        (43, 'glo_sme_token', ''),
        (44, 'glo_sme_provider', ''),
        (45, 'glo_gifting_token', ''),
        (46, 'glo_gifting_provider', ''),
        (47, 'glo_corporate_token', ''),
        (48, 'glo_corporate_provider', ''),
        (49, '9mobile_sme_token', ''),
        (50, '9mobile_sme_provider', ''),
        (51, '9mobile_gifting_token', ''),
        (52, '9mobile_gifting_provider', ''),
        (53, '9mobile_corporate_token', ''),
        (54, '9mobile_corporate_provider', ''),
        (55, 'cable_verification_token', ''),
        (56, 'cable_verification_provider', ''),
        (57,'cable_token', ''), 
        (58, 'cable_provider', ''),
        (59, 'meter_verification_token', ''),
        (60, 'meter_verification_provider', ''),
        (61, 'meter_token', ''), (62, 'meter_provider', ''),
        (63, 'exam_token', ''), (64, 'exam_provider', ''), 
        (65, 'recharge_pin_token', ''), 
        (66, 'recharge_pin_provider', ''), 
        (67, 'wallet_one_token', ''),
        (68, 'wallet_one_provider', ''), 
        (69, 'wallet_one_provider_name', ''), 
        (70, 'wallet_two_token', ''), 
        (71, 'wallet_two_provider', ''), 
        (72, 'wallet_two_provider_name', ''), 
        (73, 'wallet_three_token', ''), 
        (74, 'wallet_three_provider', ''), 
        (75, 'wallet_three_provider_name', ''), 
        (76, 'data_pin_token', ''), 
        (77, 'data_pin_provider', '')   ");
         }
    private static function create_tables() {
        global $wpdb;

        $table_name_1 = $wpdb->prefix . 'vtu_max_transactions';
        $table_name_2 = $wpdb->prefix . 'vtu_max_airtime';
        $table_name_3 = $wpdb->prefix . 'vtu_max_airtimepinprice';
        $table_name_4 = $wpdb->prefix . 'vtu_max_notifications';
        $table_name_5 = $wpdb->prefix . 'vtu_max_apiconfigs';
        $table_name_6 = $wpdb->prefix . 'vtu_max_cable_id';
        $table_name_7 = $wpdb->prefix . 'vtu_max_cable_plans';
        $table_name_8 = $wpdb->prefix . 'vtu_max_data_pins';
        $table_name_9 = $wpdb->prefix . 'vtu_max_data_plans';
        $table_name_10 = $wpdb->prefix . 'vtu_max_data_token';
        $table_name_11 = $wpdb->prefix . 'vtu_max_electricity_id';
        $table_name_12 = $wpdb->prefix . 'vtu_max_exam_id';
        $table_name_13 = $wpdb->prefix . 'vtu_max_network_id';
  
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_1'") != $table_name_1) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_1 (
              id INT AUTO_INCREMENT PRIMARY KEY,
              user_id INT,
              biller VARCHAR(255),
              description VARCHAR(255),
              ref VARCHAR(255),
              amount DECIMAL(10, 2),
              number VARCHAR(15),
              date DATE,
              status VARCHAR(50),
              old_balance DECIMAL(10, 2),
              new_balance DECIMAL(10, 2),
              profits DECIMAL(10, 2),
              created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
              updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }

        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_2'") != $table_name_2) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_2 (
              id INT(100) AUTO_INCREMENT PRIMARY KEY,
              network VARCHAR(10) NOT NULL,
              buy_price FLOAT NOT NULL DEFAULT 96,
              customer_discount FLOAT NOT NULL,
              reseller_discount FLOAT NOT NULL,
              agent_discount FLOAT NOT NULL,
              airtime_type VARCHAR(15) NOT NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        
          if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_3'") != $table_name_3) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_3 (
              id INT(100) AUTO_INCREMENT PRIMARY KEY,
              network VARCHAR(10) NOT NULL,
              customer_discount FLOAT NOT NULL,
              reseller_discount FLOAT NOT NULL,
              agent_discount FLOAT NOT NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        
          if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_4'") != $table_name_4) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_4 (
              id INT(200) AUTO_INCREMENT PRIMARY KEY,
              notificationfor TINYINT(4) NOT NULL,
              title VARCHAR(200) NOT NULL,
              message TEXT NOT NULL,
              status VARCHAR(50) NOT NULL DEFAULT 0,
              date DATETIME NOT NULL DEFAULT current_timestamp()
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        
          if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_5'") != $table_name_5) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_5 (
              id INT(200) AUTO_INCREMENT PRIMARY KEY,
              name VARCHAR(30) NOT NULL,
              value VARCHAR(100) DEFAULT NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        
          if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_6'") != $table_name_6) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_6 (
              id INT(11) AUTO_INCREMENT PRIMARY KEY,
              cable_id VARCHAR(10) DEFAULT NULL,
              provider VARCHAR(10) NOT NULL,
              provider_status VARCHAR(10) NOT NULL DEFAULT 'true'
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_7'") != $table_name_7) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_7 (
             id INT(100) AUTO_INCREMENT PRIMARY KEY,
             name VARCHAR(255) NOT NULL,
             price FLOAT NOT NULL,
             customer_price FLOAT NOT NULL,
             reseller_price FLOAT NOT NULL,
             agent_price FLOAT NOT NULL,
             plan_id VARCHAR(255) NOT NULL,
             type VARCHAR(255) DEFAULT NULL,
             cable_provider VARCHAR(10) NOT NULL,
             validity VARCHAR(255) NOT NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_8'") != $table_name_8) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_8 (
              id INT(100) AUTO_INCREMENT PRIMARY KEY,
              name VARCHAR(255) NOT NULL,
              price FLOAT NOT NULL,
              customer_price FLOAT NOT NULL,
              reseller_price FLOAT NOT NULL,
              agent_price FLOAT NOT NULL,
              plan_id VARCHAR(255) NOT NULL,
              type VARCHAR(255) DEFAULT NULL,
              data_network VARCHAR(10) NOT NULL,
              validity VARCHAR(255) NOT NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_9'") != $table_name_9) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_9 (
             id INT(100) AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(255) NOT NULL,
            price FLOAT NOT NULL,
            customer_price FLOAT NOT NULL,
            reseller_price FLOAT NOT NULL,
            agent_price FLOAT NOT NULL,
            plan_id VARCHAR(255) NOT NULL,
            type VARCHAR(255) DEFAULT NULL,
            data_network VARCHAR(10) NOT NULL,
            validity VARCHAR(255) NOT NULL
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_10'") != $table_name_10) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_10 (
            id INT(100) AUTO_INCREMENT PRIMARY KEY,
            ref VARCHAR(255) NOT NULL,
            business VARCHAR(30) NOT NULL,
            network VARCHAR(30) NOT NULL,
            data_size VARCHAR(30) NOT NULL,
            quantity INT(100) NOT NULL,
            serial TEXT NOT NULL,
            tokens TEXT NOT NULL,
            date DATETIME NOT NULL DEFAULT current_timestamp()
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_11'") != $table_name_11) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_11 (
            id INT(11) AUTO_INCREMENT PRIMARY KEY,
            electricity_id VARCHAR(50) DEFAULT NULL,
            provider VARCHAR(50) NOT NULL,
            abbreviation VARCHAR(5) NOT NULL,
            provider_status VARCHAR(10) NOT NULL DEFAULT 'true'
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_12'") != $table_name_12) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_12 (
            
            id INT(11) AUTO_INCREMENT PRIMARY KEY,
            exam_id VARCHAR(10) DEFAULT NULL,
            provider VARCHAR(50) NOT NULL,
            buying_price FLOAT NOT NULL DEFAULT 0,
            customer_price FLOAT NOT NULL DEFAULT 0,
            reseller_price FLOAT NOT NULL DEFAULT 0,
            agent_price FLOAT NOT NULL DEFAULT 0,
            provider_status VARCHAR(10) NOT NULL DEFAULT 'true'
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
        if ($wpdb->get_var("SHOW TABLES LIKE '$table_name_13'") != $table_name_13) {
            $charset_collate = $wpdb->get_charset_collate();

            $sql = "CREATE TABLE $table_name_13 (
           
            id INT(11) NOT NULL,
            network_id VARCHAR(10) NOT NULL,
            sme_id VARCHAR(10) NOT NULL,
            gifting_id VARCHAR(10) NOT NULL,
            corporate_id VARCHAR(10) NOT NULL,
            vtu_id VARCHAR(10) NOT NULL,
            sharesell_id VARCHAR(10) NOT NULL,
            network VARCHAR(20) NOT NULL,
            network_status VARCHAR(10) NOT NULL DEFAULT 'false',
            vtu_status VARCHAR(10) NOT NULL DEFAULT 'false',
            sharesell_status VARCHAR(10) NOT NULL DEFAULT 'false',
            airtimepin_status VARCHAR(10) NOT NULL DEFAULT 'false',
            sme_status VARCHAR(10) NOT NULL DEFAULT 'false',
            gifting_status VARCHAR(10) NOT NULL DEFAULT 'false',
            corporate_status VARCHAR(10) NOT NULL DEFAULT 'false',
            datapin_status VARCHAR(10) NOT NULL DEFAULT 'false'
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8;";

            dbDelta($sql);
        }
    }
}