<?php

class VtuMaxTemplateLoader {
    private $routes = array(
        'public' => array(
            '/support' => array('template' => 'template/template-vtu-max-support.php', 'title' => 'Support', 'enabled' => true),
            '/404' => array('template' => 'template/default/vtu-max-404.php', 'title' => '404 Not Found', 'enabled' => true)
        ),
        'private' => array( 
            '/' => array('template' => 'template/template-vtu-max-dashboard.php', 'title' => 'Dashboard', 'enabled' => true),   
              '/transactions' => array('template' => 'template/template-vtu-max-transactions.php', 'title' => 'Transactions', 'enabled' => true),
            '/transactions/?ref' => array('template' => 'template/template-vtu-max-transaction-details.php', 'title' => 'Transaction Details', 'enabled' => true),
            '/transaction/?status' => array('template' => 'template/template-vtu-max-transaction-status.php', 'title' => 'Transaction Status', 'enabled' => true),
            '/auth/logout' => array('template' => 'template/auth/template-vtu-max-logout.php', 'title' => 'Encrypted', 'enabled' => true),
            '/profile' => array('template' => 'template/template-vtu-max-profile.php', 'title' => 'Profile', 'enabled' => true),
            '/finance' => array('template' => 'template/template-vtu-max-finance.php', 'title' => 'Finance', 'enabled' => true), 
            '/transfer' => array('template' => 'template/pack/vtu-max-transfer.php', 'title' => 'Tranfer Funds', 'enabled' => true),
            '/airtime' => array('template' => 'template/pack/vtu-max-airtime.php', 'title' => 'Buy Airtime', 'enabled' => true),
            '/data' => array('template' => 'template/pack/vtu-max-data.php', 'title' => 'Buy Data', 'enabled' => true),
            '/datapin' => array('template' => 'template/pack/vtu-max-data.php', 'title' => 'Buy Datapin', 'enabled' => true),
            '/electricity' => array('template' => 'template/pack/vtu-max-electricity.php', 'title' => 'Pay for Electricity', 'enabled' => true),
            '/recharge' => array('template' => 'template/pack/vtu-max-airtime.php', 'title' => 'Generate Recharge Pin', 'enabled' => true),
            '/tv' => array('template' => 'template/pack/vtu-max-tv.php', 'title' => 'Renew Cable TV', 'enabled' => true), 
            '/betting' => array('template' => 'template/pack/vtu-max-betting.php', 'title' => 'Fund betting wallet', 'enabled' => true),
            '/a2cash' => array('template' => 'template/pack/vtu-max-a2cash.php', 'title' => 'Convert Airtime2Cash', 'enabled' => true),
            '/bulksms' => array('template' => 'template/pack/vtu-max-bulksms.php', 'title' => 'Send Bulk SMS', 'enabled' => true),
            '/epin' => array('template' => 'template/pack/vtu-max-exam.php', 'title' => 'Buy Epins', 'enabled' => true)
        ),
        'auth' => array(
            '/auth/login' => array('template' => 'template/auth/template-vtu-max-login.php', 'title' => 'Login', 'enabled' => true),
            '/auth/register' => array('template' => 'template/auth/template-vtu-max-register.php', 'title' => 'Register', 'enabled' => true),
            '/auth/forgot-password' => array('template' => 'template/auth/template-vtu-max-forgot-password.php', 'title' => 'Forgot Password', 'enabled' => true),
            
        )
    );

    public function __construct() {
        add_filter('template_include', array($this, 'loadViewTemplate'));
        add_filter('wp_title', array($this, 'setPageTitle'), 10, 2);
        
    }
    
    
    public function loadViewTemplate($template) {
        $current_url = wp_make_link_relative(home_url(add_query_arg(NULL, NULL)));

        if (defined('DOING_AJAX') && DOING_AJAX) {
            $this->handleAjaxRequest();
            exit;
        } else {
            $page_title = '';

            foreach ($this->routes as $type => $urls) {
                foreach ($urls as $url => $data) {
                    $url_without_params = strtok($url, '?');
                    $current_url_without_params = strtok($current_url, '?');

                    if ($current_url_without_params === $url_without_params) {
                        if (!$data['enabled']) {
                            wp_redirect(home_url());
                            exit;
                        }

                        if ($type === 'auth' && is_user_logged_in()) {
                            wp_redirect(home_url());
                            exit;
                        }

                        if ($type === 'private' && !is_user_logged_in()) {
                            wp_redirect(home_url('/auth/login'));
                            exit;
                        }

                        $template = $this->getTemplate($data['template']);
                        $page_title = $data['title'];
                        break 2;
                    }
                }
            }

            if ($current_url === '/' && is_user_logged_in()) {
                $template = $this->getTemplate('template/template-vtu-max-dashboard.php'); 
                $page_title = 'Dashboard';
                return $template;
            } elseif ($current_url === '/' && !is_user_logged_in()) {
                wp_redirect(home_url('/auth/login'));
                exit;
            }

            if (!$this->is404Page($current_url) && !is_404()) {
                wp_redirect(home_url('/404'));
                exit;
            }

            add_filter('document_title_parts', function ($title) use ($page_title) {
                $title['title'] = $page_title;
                return $title;
            });
        }

        return $template;
    }

    private function handleAjaxRequest() {
        $dashboard_content = $this->getTemplateContent('template/template-vtu-max-dashboard.php');
        echo $dashboard_content;
    }

    private function is404Page($current_url) {
        foreach ($this->routes['public'] as $url => $data) {
            if ($url === '/404' && $current_url === '/404') {
                return true;
            }
        }
        return false;
    }

    private function getTemplate($path) {
        return plugin_dir_path(__FILE__) . $path;
    }

    private function getTemplateContent($path) {
        ob_start();
        include($this->getTemplate($path));
        return ob_get_clean();
    }
}

new VtuMaxTemplateLoader();
