<?php
class VtuMax_Monnify_Webhook {

    public function register_webhook() {
        add_action('init', array($this, 'vtumax_register_monnify_webhook'));
        add_action('parse_request', array($this, 'vtumax_handle_monnify_webhook'));
    }

    public function vtumax_register_monnify_webhook() {
        add_rewrite_rule('^vtumax/webhook/monnify/?$', 'index.php?monnify_webhook=true', 'top');
        add_rewrite_tag('%monnify_webhook%', '1');
    }

    public function vtumax_handle_monnify_webhook($wp) {
        if (array_key_exists('monnify_webhook', $wp->query_vars)) {
            $this->vtumax_process_monnify_webhook();
            exit;
        }
    }

    public function vtumax_process_monnify_webhook() {
        global $wpdb;

        $raw_request = file_get_contents('php://input');
        $SECRET_KEY = $wpdb->get_var("SELECT value FROM {$wpdb->prefix}vtu_max_apiconfigs WHERE name = 'monify_secret'");
        $signature = $_SERVER['HTTP_MONNIFY_SIGNATURE'];
        $computedHash = hash_hmac('sha512', $raw_request, $SECRET_KEY);

        if ($computedHash != $signature) {
            status_header(401);
            die("Invalid Hash");
        }

        $request_array = json_decode($raw_request);

        $existing_transaction = $wpdb->get_row($wpdb->prepare("SELECT * FROM {$wpdb->prefix}vtu_max_transactions WHERE ref = %s", $request_array->eventData->transactionReference));

        if (!$existing_transaction || ($existing_transaction->status != 'PENDING' && $existing_transaction->status != 'PROCESSING')) {
            $user_email = $request_array->eventData->customer->email;
            $user_id = email_exists($user_email);

            if ($user_id) {
                $monify_charges = $wpdb->get_var("SELECT value FROM {$wpdb->prefix}vtu_max_apiconfigs WHERE name = 'monify_charges'");
                $amount_paid = $request_array->eventData->amountPaid;
                $credited_amount = $amount_paid - ($amount_paid * ($monify_charges / 100));

                $old_balance = get_user_meta($user_id, 'wallet_balance', true);

                if ($old_balance === '') {
                    error_log('Error: User balance not found for user with ID ' . $user_id);
                    exit;
                }
                $profit = $amount_paid - $credited_amount;
                $new_balance = $old_balance + $credited_amount;

                $table_name_transactions = $wpdb->prefix . 'vtu_max_transactions';

$result = $wpdb->insert(
    $table_name_transactions,
    array(
        'user_id' => $user_id,
        'biller' => 'MFY NG',
        'description' => 'wallet funding of ₦'. $amount_paid . ' from vitual account',
        'ref' => $request_array->eventData->transactionReference,
        'amount' => $credited_amount,
        'number' => $request_array->eventData->destinationAccountInformation->accountNumber,
        'date' => current_time('mysql'),
        'status' => 'success',
        'old_balance' => $old_balance,
        'new_balance' => $new_balance,
        'profits' => $profit,
        'created_at' => current_time('mysql'),
        'updated_at' => current_time('mysql'),
    )
);

if ($result === false) {
    // Log error if the transaction insertion fails
    error_log('Error: Transaction insertion failed. MySQL Error: ' . $wpdb->last_error);
}


                update_user_meta($user_id, 'wallet_balance', $new_balance);
            } else {
                error_log('Error: User not found for email ' . $user_email);
            }
        } else {
            error_log('Error: Transaction with ref ' . $request_array->eventData->transactionReference . ' already exists.');
        }

        status_header(200);
        exit;
    }
}

$monnify_webhook_handler = new VtuMax_Monnify_Webhook();
$monnify_webhook_handler->register_webhook();