<?php
global $wpdb;

function process_transaction($user_id, $transaction_type, $transaction_ref, $amount) {
    global $wpdb;
    $transaction_type = sanitize_text_field($transaction_type);
    $transaction_ref = sanitize_text_field($transaction_ref);
    $amount = abs(floatval(sanitize_text_field($amount))); 
    $old_balance = get_user_meta($user_id, 'wallet_balance', true);
    $desc = sanitize_text_field($_POST['desc']);
    $new_balance = ($transaction_type === 'credit') ? $old_balance + $amount : $old_balance - $amount;
    if ($new_balance < 0) {
        return 'Debit Amount exceeds available balance. Transaction failed';
    }
    
$wpdb->insert(
    $wpdb->prefix . 'vtu_max_transactions',
    array(
        'user_id' => $user_id,
        'biller' => 'Admin',
        'description' => $desc,
        'ref' => $transaction_ref,
        'amount' => $amount,
        'number' => '',
        'date' => current_time('mysql'),
        'status' => 'success', 
        'old_balance' => $old_balance,
        'new_balance' => $new_balance,
        'profits' => 0,
    ),
    array('%d', '%s', '%s', '%s', '%f', '%s', '%s', '%s', '%f', '%f', '%f') // Updated data types
);
    update_user_meta($user_id, 'wallet_balance', $new_balance);

    return 'Transaction processed successfully.';
}

function display_users_table() {
    $users_info = get_users_info();
    ?><table class="wp-list-table widefat fixed striped">
    <thead>
        <tr>
            <th class="manage-column">Username</th>
            <th class="manage-column">Wallet Balance</th>
            <th class="manage-column">Total Transactions</th>
            <th class="manage-column">Action</th>
        </tr>
    </thead>
    <tbody>
        <?php foreach ($users_info as $user_info) : ?>
            <tr>
                <td><?php echo esc_html($user_info['username']); ?></td>
                <td><?php echo esc_html($user_info['wallet_balance']); ?></td>
                <td><?php echo esc_html($user_info['total_transactions']); ?></td>
                <td>
                    <form method="post" action="">
                        <input type="hidden" name="user_id" value="<?php echo esc_attr($user_info['user_id']); ?>">
                        <input type="hidden" name="transaction_ref" value="<?php echo esc_attr(generateTransactionRef()); ?>">
                        <select name="transaction_type" value="">
                            <option value="credit">Credit</option>
                            <option value="debit">Debit</option>
                        </select>
                        <input class="input" type=text name="desc" placeholder="description">
                        <input type="number" name="amount" placeholder="Amount">
                        <button type="submit" name="process_transaction" class="button">Proceed</button>
                    </form>
                </td>
            </tr>
        <?php endforeach; ?>
    </tbody>
</table>

    <?php
}

if (isset($_POST['process_transaction'])) {
    $user_id = absint($_POST['user_id']);
    $transaction_type = sanitize_text_field($_POST['transaction_type']);
    $transaction_ref = sanitize_text_field($_POST['transaction_ref']);
    $desc = sanitize_text_field($_POST['desc']);
    $amount = abs(floatval(sanitize_text_field($_POST['amount'])));

    $result = process_transaction($user_id, $transaction_type, $transaction_ref, $amount);
    echo '<p>' . $result . '</p>';
}

display_users_table();
function get_users_info() {
    $users = get_users();
    $users_info = array();

    foreach ($users as $user) {
        $user_id = $user->ID;
        $username = $user->user_login;
        $wallet_balance = get_user_meta($user_id, 'wallet_balance', true);

global $wpdb;
$table_name = $wpdb->prefix . 'vtu_max_transactions';
$total_transactions = $wpdb->get_var(
    $wpdb->prepare(
        "SELECT COUNT(*) FROM {$table_name} WHERE user_id = %d",
        $user_id
    )
);

        $users_info[] = array(
            'user_id' => $user_id,
            'username' => $username,
            'wallet_balance' => $wallet_balance,
            'total_transactions' => $total_transactions,
        );
    }
    return $users_info;
}
function generateTransactionRef() {
    $characters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789';
    $x = substr(str_shuffle($characters), 0, 7);
    return 'MAX-' . $x . current_time('timestamp');
}
