jQuery(document).ready(function ($) {
    $('#login-button').on('click', function () {
       
        $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

        
        var username = $('#username').val();
        var password = $('#toggle-password').val();

       
        if (!username && !password) {
            
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            
            resetButtonState();
            return;
        } else if (!username) {
            
            showToast('Username is required', 'linear-gradient(to right, #ff416c, #ff4b2b)');
           
            resetButtonState();
            return;
        } else if (!password) {
            
            showToast('Enter your password', 'linear-gradient(to right, #ff416c, #ff4b2b)');
           
            resetButtonState();
            return;
        }

        $.ajax({
            url: ajax_object.ajax_url,
            type: 'POST',
            data: {
                action: 'vtu_max_login',
                username: username,
                password: password,
                security: $('#security').val(),
            },
            success: function (response) {
                if (response.success) {
                    showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                   
                    if (response.redirect) {
                        window.location.href = response.redirect;
                    }
                } else {
                    showToast(response.message || 'An error occurred. Please try again.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
                }

               
                resetButtonState();
            },
            error: function (xhr, status, error) {
                console.error(xhr.responseText);

                
                showToast('An error occurred. Please try again.', 'linear-gradient(to right, #ff416c, #ff4b2b)');

                
                resetButtonState();
            },
        });
    });

    
    function showToast(message, backgroundColor) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top', 
            position: 'center',
            backgroundColor: backgroundColor,
        }).showToast();
    }

    
    function resetButtonState() {
        $('#login-button').html('Login now').prop('disabled', false);
    }
});

jQuery(document).ready(function ($) {
    $('#register-button').on('click', function (event) {
        event.preventDefault();

        $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

        
        var formData = {
            action: 'vtu_max_register',
            fullname: sanitizeInput($('#fullname').val()),
            email: sanitizeInput($('#email').val()),
            username: sanitizeInput($('#username').val()),
            refCode: sanitizeInput($('#refCode').val()),
            password: sanitizeInput($('#toggle-password').val()),
            security: $('#security').val(),
        };

        
        if (!isValidInput(formData.fullname) || !isValidInput(formData.email) || !isValidInput(formData.username) || !isValidInput(formData.password)) {
            showToast('Please fill in all fields with valid input.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        }

        
        if (formData.fullname.toLowerCase().includes('hacker') || formData.fullname.toLowerCase().includes('admin')) {
            showToast('Full name is not valid.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        }

        $.ajax({
            url: ajax_object.ajax_url,
            type: 'POST',
            data: formData,
            success: function (response) {
                if (response.success) {
                    showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                    if (response.redirect) {
                        window.location.href = response.redirect;
                    }
                } else {
                    showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                }

                resetButtonState();
            },
            error: function (xhr, status, error) {
                console.error(xhr.responseText);
                showToast('An error occurred. Please try again.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
                resetButtonState();
            },
        });
    });

    function sanitizeInput(value) {
        
        return $.trim(value); 
    }

    function isValidInput(value) {
        // 
        return value !== '';
    }

    function showToast(message, backgroundColor) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: backgroundColor,
        }).showToast();
    }

    function resetButtonState() {
        $('#register-button').html('Create An Account').prop('disabled', false);
    }
});
jQuery(document).ready(function ($) {
    $('#buyAirtime').on('click', function () {
        var network = $('#data-attr').val();
        var amount = $('#amount').val();
        var phone = $('#phone').val();

        if (network === 'none' || !amount || !phone) {
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            return;
        }

        Swal.fire({
            title: 'Confirm Transaction',
            text: 'You are about to purchase ₦' + amount + ' worth of airtime for ' + phone,
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: 'Proceed',
            cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_airtime_purchase',
                        network: network,
                        amount: amount,
                        phone: phone,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#buyAirtime').html('Continue').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
});
jQuery(document).ready(function ($) {
    $('#buyData').on('click', function () {
        var network = $('#data-attr').val();
        var dtype = $('#dtype').val();
        var plan = $('#plan').val();
        var phone = $('#phone').val();

if (network === 'none' || !$('#data-attr').val() || !dtype || !plan || !phone) {
    showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
    return;
}Swal.fire({
    title: 'Confirm Transaction',
    text: 'You are about to purchase ' + plan + ' ' + network.toUpperCase() + ' for ' + phone,
    icon: 'info',
    showCancelButton: true,
    confirmButtonText: 'Proceed',
    cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_data_purchase',
                        network: network,
                        dtype: dtype,
                        plan: plan,
                        phone: phone,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#buyData').html('Continue').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
});

jQuery(document).ready(function ($) {
    $('#buyEpin').on('click', function () {
        var examtype = $('#data-attr').val();
        var amount = $('#amount').val();
        var total = $('#total').val();

if (examtype === 'none' || !$('#data-attr').val() || !amount || !total ) {
    showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
    return;
}Swal.fire({
    title: 'Confirm Transaction',
    text: 'You are about to purchase ' + total + ' ' + examtype.toUpperCase() + ' ePins at price ₦' + amount,
    icon: 'info',
    showCancelButton: true,
    confirmButtonText: 'Proceed',
    cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_buy_epin',
                      
                        examtype: examtype,
                        total: total,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#buyEpin').html('Continue').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
});
jQuery(document).ready(function ($) {
    $('#verNINbtn').on('click', function () {
        var NIN = $('#NIN').val();
        var phone = $('#phone').val();

        if ( !NIN || !phone) {
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            return;
        }

        Swal.fire({
            title: 'Confirm Verification',
            text: 'You are about to verify your Account with NIN: ' + NIN,
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: 'Authorize',
            cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_kyc',
                        NIN: NIN,
                        phone: phone,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#verNINbtn').html('Verify NIN now').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
});
jQuery(document).ready(function ($) {
    $('#verBVNbtn').on('click', function () {
        var BVN = $('#BVN').val();
        var phone = $('#phone').val();

        if ( !BVN || !phone) {
            showToast('Please fill in all fields. bb', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            return;
        }

        Swal.fire({
            title: 'Confirm Verification',
            text: 'You are about to verify your Account with BVN: ' + BVN,
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: 'Authorize',
            cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_kyc',
                        BVN: BVN,
                        phone: phone,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#verBVNbtn').html('Verify BVN now').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
});


jQuery(document).ready(function ($) {
    $('#updateMaxPassword').on('click', function () {
       
        $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

        
        var oldpassword = $('#oldpassword').val();
        var newpassword = $('#newpassword').val();
        var cnewpassword = $('#cnewpassword').val();
       
        if (!oldpassword && !newpassword && !cnewpassword) {
            
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            
            resetButtonState();
            return;
        } else if (!oldpassword) {
            
            showToast('Enter previous password', 'linear-gradient(to right, #ff416c, #ff4b2b)');
           
            resetButtonState();
            return;
        } else if (!cnewpassword) {
            
            showToast('Confirm New password', 'linear-gradient(to right, #ff416c, #ff4b2b)');
           
            resetButtonState();
            return;
        } else if (!newpassword) {
            
            showToast('Enter your new password', 'linear-gradient(to right, #ff416c, #ff4b2b)');
           
            resetButtonState();
            return;
        }

        $.ajax({
            url: ajax_object.ajax_url,
            type: 'POST',
            data: {
                action: 'vtu_max_update_password',
                oldpassword: oldpassword,
                newpassword: newpassword,
                cnewpassword: cnewpassword,
                security: $('#security').val(),
            },
            success: function (response) {
                if (response.success) {
                    showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                   
                    if (response.redirect) {
                        window.location.href = response.redirect;
                    }
                } else {
                    showToast(response.message || 'An error occurred. Please try again.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
                }

               
                resetButtonState();
            },
            error: function (xhr, status, error) {
                console.error(xhr.responseText);

                
                showToast('An error occurred. Please try again.', 'linear-gradient(to right, #ff416c, #ff4b2b)');

                
                resetButtonState();
            },
        });
    });

    
    function showToast(message, backgroundColor) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top', 
            position: 'center',
            backgroundColor: backgroundColor,
        }).showToast();
    }

    
    function resetButtonState() {
        $('#updateMaxPassword').html('Update Password').prop('disabled', false);
    }
});

jQuery(document).ready(function ($) {
    $('#payElectricity').on('click', function () {
        $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

        var provider = $('#data-attr').val();
        var etype = $('#etype').val();
        var amount = $('#amount').val();
        var meterno = $('#meterno').val();

        if (provider === 'none' || !etype || !meterno || !amount) {
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        } else if (!provider) {
            showToast('Kindly select electricity provider', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        } else if (!etype) {
            showToast('Select Electricity type', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        }

        $.ajax({
            url: ajax_object.ajax_url,
            type: 'POST',
            data: {
                action: 'vtu_max_verify_electricity',
                provider: provider,
                etype: etype,
                meterno: meterno,
                amount: amount,
                security: $('#security').val(),
            },
            success: function (response) {
                if (response.success) {
                    Swal.fire({
                        title: 'Confirm Transaction',
                        text: response.message + ' Do you want to proceed?',
                        icon: 'info',
                        showCancelButton: true,
                        confirmButtonText: 'Proceed',
                        cancelButtonText: 'Cancel'
                    }).then((result) => {
                        if (result.isConfirmed) {
                            $.ajax({
                                url: ajax_object.ajax_url,
                                type: 'POST',
                                data: {
                                    action: 'vtu_max_pay_electricity',
                                    provider: provider,
                                    etype: etype,
                                    meterno: meterno,
                                    amount: amount,
                                    security: $('#security').val(),
                                },
                                success: function (finalResponse) {
                                    if (finalResponse.success) {
                                        showToast(finalResponse.message, 'linear-gradient(to right, #00b09b, #96c93d)'); 
                                        resetButtonState();
                                        if (finalResponse.redirect) {
                                            window.location.href = finalResponse.redirect;
                                        }
                                    } else {
                                        showToast(finalResponse.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                                        resetButtonState();
                                    }
                                },
                                error: function (xhr, status, error) {
                                    var errorMessage = 'An error occurred. Please try again.';
                                    if (xhr.responseJSON && xhr.responseJSON.message) {
                                        errorMessage = xhr.responseJSON.message;
                                    }
                                    showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                                    resetButtonState();
                                },
                            });
                        } else {
                            resetButtonState();
                        }
                    });
                } else {
                    showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                    resetButtonState();
                }
            },
            error: function (xhr, status, error) {
                var errorMessage = 'An error occurred. Please try again.';
                if (xhr.responseJSON && xhr.responseJSON.message) {
                    errorMessage = xhr.responseJSON.message;
                }
                showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                resetButtonState();
            },
        });
    });

    function showToast(message, backgroundColor) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top', 
            position: 'center',
            backgroundColor: backgroundColor,
        }).showToast();
    }

    function resetButtonState() {
        $('#payElectricity').html('Continue').prop('disabled', false);
    }
});
jQuery(document).ready(function ($) {
    $('#subTv').on('click', function () {
        $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

        var provider = $('#data-attr').val();
        var iuc = $('#iuc').val();
        var plan = $('#plan').val();
        

        if (provider === 'none' || !iuc || !plan) {
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        } else if (!provider) {
            showToast('Kindly select Cable Tv provider', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        } else if (!iuc) {
            showToast('Enter IUC/Smartcard Number', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            resetButtonState();
            return;
        }

        $.ajax({
            url: ajax_object.ajax_url,
            type: 'POST',
            data: {
                action: 'vtu_max_verify_tv',
                provider: provider,
                iuc: iuc,
                plan: plan,
                security: $('#security').val(),
            },
            success: function (response) {
                if (response.success) {
                    Swal.fire({
                        title: 'Confirm Transaction',
                        text: response.message + '<br> Do you want to proceed?',
                        icon: 'info',
                        showCancelButton: true,
                        confirmButtonText: 'Proceed',
                        cancelButtonText: 'Cancel'
                    }).then((result) => {
                        if (result.isConfirmed) {
                            $.ajax({
                                url: ajax_object.ajax_url,
                                type: 'POST',
                                data: {
                                    action: 'vtu_max_pay_tv',
                                    provider: provider,
                                    iuc: iuc,
                                    plan: plan,
                                    security: $('#security').val(),
                                },
                                success: function (finalResponse) {
                                    if (finalResponse.success) {
                                        showToast(finalResponse.message, 'linear-gradient(to right, #00b09b, #96c93d)'); 
                                        resetButtonState();
                                        if (finalResponse.redirect) {
                                            window.location.href = finalResponse.redirect;
                                        }
                                    } else {
                                        showToast(finalResponse.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                                        resetButtonState();
                                    }
                                },
                                error: function (xhr, status, error) {
                                    var errorMessage = 'An error occurred. Please try again.';
                                    if (xhr.responseJSON && xhr.responseJSON.message) {
                                        errorMessage = xhr.responseJSON.message;
                                    }
                                    showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                                    resetButtonState();
                                },
                            });
                        } else {
                            resetButtonState();
                        }
                    });
                } else {
                    showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                    resetButtonState();
                }
            },
            error: function (xhr, status, error) {
                var errorMessage = 'An error occurred. Please try again.';
                if (xhr.responseJSON && xhr.responseJSON.message) {
                    errorMessage = xhr.responseJSON.message;
                }
                showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                resetButtonState();
            },
        });
    });

    function showToast(message, backgroundColor) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top', 
            position: 'center',
            backgroundColor: backgroundColor,
        }).showToast();
    }

    function resetButtonState() {
        $('#subTv').html('Continue').prop('disabled', false);
    }
});
jQuery(document).ready(function ($) {
    $('#transfer').on('click', function () {
        
        var amount = $('#amount').val();
        var tag = $('#tag').val();

        if (!amount || !tag) {
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            return;
        }

        Swal.fire({
            title: 'Confirm Transaction',
            text: 'You are about to Transfer ₦' + amount + ' to  ' + tag,
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: 'Proceed',
            cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_transfer',
                        amount: amount,
                        tag: tag,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#transfer').html('Continue').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
});
jQuery(document).ready(function ($) {
    $('#payBetting').on('click', function () {
        var provider = $('#data-attr').val();
        var amount = $('#amount').val();
        var bettingid = $('#bettingid').val();

        if (provider === 'none' || !amount || !bettingid) {
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            return;
        }

        Swal.fire({
            title: 'Confirm Transaction',
            text: 'You are about to fund your ' + provider +' Account with ₦' + amount + ' for ID:' + bettingid,
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: 'Proceed',
            cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_pay_betting',
                        provider: provider,
                        amount: amount,
                        bettingid: bettingid,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#payBetting').html('Continue').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
}); 
jQuery(document).ready(function ($) {
    $('sendBulksms').on('click', function () {
        var sender = $('#sender').val();
        var smstype = $('#smstype').val();
        var recipients = $('#recipients').val(); 
        var message = $('#message').val();
        var amount = $('#total').val();
        if (!sender || !smstype || ! recipients || !message) {
            showToast('Please fill in all fields.', 'linear-gradient(to right, #ff416c, #ff4b2b)');
            return;
        }

        Swal.fire({
            title: 'Confirm Transaction',
            text: 'You will charged ₦' + amount + ' for sending a bulk message to the following recipients: ' + recipients,
            icon: 'info',
            showCancelButton: true,
            confirmButtonText: 'Proceed',
            cancelButtonText: 'Cancel'
        }).then((result) => {
            if (result.isConfirmed) {
                $(this).html('<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span>&nbsp;&nbsp; Processing...').prop('disabled', true);

                $.ajax({
                    url: ajax_object.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'vtu_max_bulk_sms',
                        smstype: smstype,
                        sender: sender,
                        message: message,
                        recipients: recipients,
                        security: $('#security').val(),
                    },
                    success: function (response) {
                        if (response.success) {
                            showToast(response.message, 'linear-gradient(to right, #00b09b, #96c93d)');
                            if (response.redirect) {
                                window.location.href = response.redirect;
                            }
                        } else {
                            showToast(response.message, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        }
                        resetButtonState();
                    },
                    error: function (xhr, status, error) {
                        console.error(xhr.responseText);
                        var errorMessage = 'An error occurred. Please try again.';
                        if (xhr.responseJSON && xhr.responseJSON.message) {
                            errorMessage = xhr.responseJSON.message;
                        }
                        showToast(errorMessage, 'linear-gradient(to right, #ff416c, #ff4b2b)');
                        resetButtonState();
                    },
                });
            }
        });
    });

    function resetButtonState() {
        $('#buyAirtime').html('Continue').prop('disabled', false);
    }

    function showToast(message, background) {
        Toastify({
            text: message,
            duration: 3000,
            gravity: 'top',
            position: 'center',
            backgroundColor: background,
            callback: function (instance) {
                instance.el.style.borderRadius = '100px';
            }
        }).showToast();
    }
}); 


