<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://author.vtumax.com.ng
 * @since             1.0.0
 * @package           Vtu_Max
 *
 * @wordpress-plugin
 * Plugin Name:       VTUmax 
 * Plugin URI:        https://vtumax.com
 * Description:       A reliable and secure VTU plugin for WordPress websites that allows you to sell SME data, utility bill payments, and other services on your website.
 * Version:           1.1.3
 * Author:            Ani Anthony
 * Author URI:        https://developers.vtumax.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       vtu-max
 * Domain Path:       /languages
 */


if (!defined('WPINC')) { die; }

define('VTU_MAX_VERSION', '1.1.3');

function activate_vtu_max() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-vtu-max-activator.php';
    Vtu_Max_Activator::activate();
}

function deactivate_vtu_max() {
    require_once plugin_dir_path(__FILE__) . 'includes/class-vtu-max-deactivator.php';
    Vtu_Max_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_vtu_max');
register_deactivation_hook(__FILE__, 'deactivate_vtu_max');

require plugin_dir_path(__FILE__) . 'includes/class-vtu-max.php';

add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'vtu_max_plugin_action_links');
function vtu_max_plugin_action_links($links) {
    $links['settings'] = '<a href="' . admin_url('admin.php?page=vtu-max-api-config') . '">Settings</a>';
    $links['upgrade'] = '<a href="' . admin_url('admin.php?page=vtu-max-upgrade') . '">Upgrade</a>';
    return $links;
}

function run_vtu_max() {
    $plugin = new Vtu_Max();
    $plugin->run();
    
    check_vtu_max_updates();
}

run_vtu_max();

function check_vtu_max_updates() {
    $update_info = wp_remote_get('https://cdn.vtumax.com/plugin/vtumax/update.json');

    if (!is_wp_error($update_info) && $update_info['response']['code'] === 200) {
        $update_data = json_decode($update_info['body'], true);

        $installed_version = VTU_MAX_VERSION;
        $latest_version = $update_data['version'];

        if (version_compare($latest_version, $installed_version, '>')) {
            $update_image_url = 'https://vtumax.com/images/favicon.png'; 

            add_action('admin_notices', function () use ($update_image_url) {
                $update_page_url = admin_url('admin.php?page=vtu-max-upgrade');
                echo '<div class="notice notice-info"><p><img src="' . esc_url($update_image_url) . '" alt="Plugin Update Image" width="32" height="32" style="vertical-align: middle;"> A new update for VTUmax is available! <a href="' . esc_url($update_page_url) . '">Update now</a>.</p></div>';
            });

            add_filter('pre_set_site_transient_update_plugins', 'vtu_max_update_transient');
        }
    }
}

function vtu_max_update_transient($transient) {
    if (!is_object($transient)) {
        $transient = new stdClass(); 
    }

    $update_info = wp_remote_get('https://cdn.vtumax.com/plugin/vtumax/update.json');

    if (!is_wp_error($update_info) && $update_info['response']['code'] === 200) {
        $update_data = json_decode($update_info['body'], true);

        $plugin_basename = plugin_basename(__FILE__);
        $plugin_dirname = dirname($plugin_basename); 
        $plugin_data = get_plugin_data(__FILE__);
        $current_version = $plugin_data['Version'];

        if (version_compare($update_data['version'], $current_version, '>')) {
            $transient->response[$plugin_basename] = (object) array(
                'new_version' => $update_data['version'],
                'package' => $update_data['package'],
                'slug' => $plugin_dirname, 
                'url' => $plugin_data['PluginURI'],
                'plugin' => plugin_basename(__FILE__)
            );
        }
    }

    return $transient;
}
add_filter('site_transient_update_plugins', 'vtu_max_update_transient');